#
# spec file for package python-fastnumbers
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         skip_python2 1
Name:           python-fastnumbers
Version:        3.2.1
Release:        1.7
Summary:        Drop-in replacement for Python's int and float
License:        MIT
URL:            https://github.com/SethMMorton/fastnumbers
Source:         https://files.pythonhosted.org/packages/source/f/fastnumbers/fastnumbers-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module typing-extensions}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module hypothesis}
BuildRequires:  %{python_module pytest >= 5}
BuildRequires:  python3-testsuite
# /SECTION
%python_subpackages

%description
fastnumbers is a Python module with three objectives:

1. To provide drop-in replacements for the Python built-in `int` and
   `float` that, on average, are around 2x faster. These functions
   should behave identically to the Python built-ins except for a few
   specific corner-cases as mentioned in the API documentation.
2. To provide a set of convenience functions that wrap the above int
   and float replacements and provide error handling.
3. To provide a set of functions that can be used to identify whether
   an input could be converted to int or float.

%prep
%setup -q -n fastnumbers-%{version}

%build
export CFLAGS="%{optflags}"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
%{python_expand export PYTHONPATH=%{buildroot}%{$python_sitearch}
pytest-%{$python_bin_suffix}
}

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitearch}/*

%changelog
* Sun Jan 23 2022 Dirk Müller <dmueller@suse.com>
- update to 3.2.1:
  * Support for Python 3.10
  * Full coverage of mypy type-checking
  * Support for Python 3.5
* Mon Apr 19 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to 3.1.0:
  * Added
    + query_type function to determine what as type fastnumbers will
    interpret a given input
  * Fixed
    + Support for Python 3.9 (eliminate use of private Python C function
    that is now hidden in 3.9)
* Thu Jan 30 2020 Todd R <toddrme2178@gmail.com>
- Update to 3.0.0
  + Added
  * Support and tests for Python 3.8
  * Text to highlight that `fastnumbers` is not always faster that native Python
  * `on_fail` option that is identical to `key`, but has a more descriptive name
  * Windows testing to Travis-CI
  * Code quality checks to Travis-CI
  * Deployment from Travis-CI
  * RELEASING.md
  + Changed
  * Cleaned up all test code so that it no longer includes unused code
    and also conformes to flake8/black
  * Near-complete re-write of the README, hopefully to make the functionality
    of `fastnumbers` clearer, to support better navigation, and to better
    highlight caveats.
  * Made all named options keyword-only except for `default`
  + Deprecated
  * `key` function (it will forever remain allowed, but is "hidden" and cannot
    be given with `on_fail`)
  + Fixed
  * Bug where the `coerce` option of `real()` was ignored
  * Improved testing reproducibility by pinning all test dependencies
  + Removed
  * Support for Python 2.7 and Python 3.4
  * Appveyor service
* Mon Aug 26 2019 Todd R <toddrme2178@gmail.com>
- Fix spurious test failure
* Tue May 21 2019 Andreas Schwab <schwab@suse.de>
- Remove arch restriction
* Wed Apr 17 2019 pgajdos@suse.com
- version update to 2.2.1
  * Formatting docstring
  * Add `allow_underscores` option to toggle whether or not underscores
  are allowed inside numbers on Python >= 3.6
  * Update CHANGELOG format to style from https://keepachangelog.com/
* Tue Feb  5 2019 Matej Cepl <mcepl@suse.com>
- Add missing python3-testsuite BR
* Sun Sep 30 2018 Arun Persaud <arun@gmx.de>
- update to version 2.1.1:
  * Fix compile error on FreeBSD where fastnumbers’ “string.h”
    shadowed the system “string.h”.
  * Add a high-level description of the fastnumbers algorithm in the
    documentation.
- changes from version 2.1.0:
  * Fix bug in converting unicode numbers on Python 3.7.
  * Restructure code base, hopefully improving simplicity.
  * Speedup of conversions of ASCII-like unicode in Python 3.
  * Speedup of conversions for large integers and large floats -
    fastnumbers should now be at least as fast as built-in functions.
- changes from version 2.0.5:
  * Fix bug in fast_real that resulted in an OverflowError when given
    very large int-like floats.
  * Source files are sorted before compilation.
* Sun Jul 29 2018 jengelh@inai.de
- Update description.
* Wed May  9 2018 toddrme2178@gmail.com
- Update to 2.0.4
  * Updated docstrings.
  * Improved timing documentation.
  * Added testing for Python 3.7.
* Thu Oct 19 2017 toddrme2178@gmail.com
- Initial version
